chronojump r466 - in trunk: . build/data glade images images/mini src src/execute src/gui src/sqlite



Author: xaviblas
Date: Mon Mar  2 16:27:09 2009
New Revision: 466
URL: http://svn.gnome.org/viewvc/chronojump?rev=466&view=rev

Log:
0.8.2.4
db 0.64
Added Margaria test: calculates power (only pending to add the longDescription in program)


Added:
   trunk/images/margaria.png   (contents, props changed)
   trunk/images/mini/margaria.png   (contents, props changed)
Modified:
   trunk/Makefile
   trunk/build/data/chronojump.prg
   trunk/build/data/chronojump_mini.prg
   trunk/build/data/version.txt
   trunk/changelog.txt
   trunk/glade/chronojump.glade
   trunk/src/chronojump.cs
   trunk/src/execute/run.cs
   trunk/src/exportSession.cs
   trunk/src/gui/chronojump.cs
   trunk/src/gui/run.cs
   trunk/src/runType.cs
   trunk/src/sqlite/main.cs
   trunk/src/sqlite/runType.cs
   trunk/src/treeViewRun.cs
   trunk/version.txt

Modified: trunk/Makefile
==============================================================================
--- trunk/Makefile	(original)
+++ trunk/Makefile	Mon Mar  2 16:27:09 2009
@@ -69,6 +69,7 @@
 		-resource:images/jump_rj_hexagon.png,jump_rj_hexagon.png 	-resource:images/mini/jump_rj_hexagon.png,mini/jump_rj_hexagon.png \
 		-resource:images/run_simple.png,run_simple.png 			-resource:images/mini/run_simple.png,mini/run_simple.png \
 		-resource:images/run_interval.png,run_interval.png 		-resource:images/mini/run_interval.png,mini/run_interval.png \
+		-resource:images/margaria.png,margaria.png			-resource:images/mini/margaria.png,mini/margaria.png \
 		-resource:images/pulse_free.png,pulse_free.png 			-resource:images/mini/pulse_free.png,mini/pulse_free.png \
 		-resource:images/pulse_custom.png,pulse_custom.png		-resource:images/mini/pulse_custom.png,mini/pulse_custom.png \
 		-resource:images/mtgug.png,mtgug.png				-resource:images/mini/mtgug.png,mini/mtgug.png \

Modified: trunk/build/data/chronojump.prg
==============================================================================
Binary files. No diff available.

Modified: trunk/build/data/chronojump_mini.prg
==============================================================================
Binary files. No diff available.

Modified: trunk/build/data/version.txt
==============================================================================
--- trunk/build/data/version.txt	(original)
+++ trunk/build/data/version.txt	Mon Mar  2 16:27:09 2009
@@ -1 +1 @@
-0.8.2.3
+0.8.2.4

Modified: trunk/changelog.txt
==============================================================================
--- trunk/changelog.txt	(original)
+++ trunk/changelog.txt	Mon Mar  2 16:27:09 2009
@@ -1,7 +1,6 @@
 TODO:
 
 Add Cabedo's tests
-Add Margaria
 
 add "chronopic3" to ping. maybe need to ask user
 
@@ -14,9 +13,25 @@
 
 do the ping gets real IP
 
+SEvaluator must be also local, and when edit, upload it. On the other hand, if
+it's only on server, we need to call server to know our values And it will be
+easy that users can know the evaluator data of others.
+mybe the best is have an SEvaluator local table iwht only one register.
+There's a need of a bool telling if it has been updated since last change or
+not.
+Then there's no need of evaluatorUniqueID in preferences.
 upload SEvaluator and edit it and re-upload
 add chronopic and device code th SEvaluator and update the diagram
 
+hide name in persons of server: replace it with uniqueID on insertion
+
+
+2 mar 2009 (2)
+	0.8.2.4
+	db 0.64
+	Added Margaria test: calculates power (only pending to add the
+	longDescription in program)
+
 2 mar 2009
 	0.8.2.3
 	Added a cancel to splash window to allow cancel ping on start (good

Modified: trunk/glade/chronojump.glade
==============================================================================
--- trunk/glade/chronojump.glade	(original)
+++ trunk/glade/chronojump.glade	Mon Mar  2 16:27:09 2009
@@ -6047,7 +6047,7 @@
 	  </child>
 
 	  <child>
-	    <widget class="GtkLabel" id="label_meters">
+	    <widget class="GtkLabel" id="label_distance_units">
 	      <property name="visible">True</property>
 	      <property name="label" translatable="yes">meters</property>
 	      <property name="use_underline">False</property>
@@ -8487,7 +8487,7 @@
 		      <signal name="activate" handler="on_new_activate" last_modification_time="Wed, 22 Sep 2004 23:55:11 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3891">
+			<widget class="GtkImage" id="image3996">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-new</property>
 			  <property name="icon_size">1</property>
@@ -8508,7 +8508,7 @@
 		      <signal name="activate" handler="on_open_activate" last_modification_time="Wed, 22 Sep 2004 23:55:11 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3892">
+			<widget class="GtkImage" id="image3997">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-open</property>
 			  <property name="icon_size">1</property>
@@ -8529,7 +8529,7 @@
 		      <signal name="activate" handler="on_edit_session_activate" last_modification_time="Tue, 26 Jul 2005 19:12:07 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3893">
+			<widget class="GtkImage" id="image3998">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -8551,7 +8551,7 @@
 		      <signal name="activate" handler="on_delete_session_activate" last_modification_time="Thu, 28 Jul 2005 13:37:42 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3894">
+			<widget class="GtkImage" id="image3999">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -8579,7 +8579,7 @@
 		      <signal name="activate" handler="on_export_session_activate" last_modification_time="Sat, 12 Feb 2005 21:57:07 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3895">
+			<widget class="GtkImage" id="image4000">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-convert</property>
 			  <property name="icon_size">1</property>
@@ -8614,7 +8614,7 @@
 		      <property name="use_underline">True</property>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3896">
+			<widget class="GtkImage" id="image4001">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-connect</property>
 			  <property name="icon_size">1</property>
@@ -8682,7 +8682,7 @@
 		      <signal name="activate" handler="on_preferences_activate" last_modification_time="Mon, 04 Oct 2004 19:19:19 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3897">
+			<widget class="GtkImage" id="image4002">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-preferences</property>
 			  <property name="icon_size">1</property>
@@ -8709,7 +8709,7 @@
 		      <signal name="activate" handler="on_quit1_activate" last_modification_time="Wed, 22 Sep 2004 23:17:31 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3898">
+			<widget class="GtkImage" id="image4003">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-quit</property>
 			  <property name="icon_size">1</property>
@@ -8743,7 +8743,7 @@
 		      <signal name="activate" handler="on_person_add_single_activate" last_modification_time="Thu, 18 Aug 2005 23:07:39 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3899">
+			<widget class="GtkImage" id="image4004">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-new</property>
 			  <property name="icon_size">1</property>
@@ -8764,7 +8764,7 @@
 		      <signal name="activate" handler="on_person_add_multiple_activate" last_modification_time="Thu, 18 Aug 2005 23:01:23 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3900">
+			<widget class="GtkImage" id="image4005">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-new</property>
 			  <property name="icon_size">1</property>
@@ -8791,7 +8791,7 @@
 		      <signal name="activate" handler="on_recuperate_person_activate" last_modification_time="Sun, 12 Dec 2004 00:40:31 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3901">
+			<widget class="GtkImage" id="image4006">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-open</property>
 			  <property name="icon_size">1</property>
@@ -8812,7 +8812,7 @@
 		      <signal name="activate" handler="on_recuperate_persons_from_session_activate" last_modification_time="Tue, 26 Jul 2005 19:12:07 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3902">
+			<widget class="GtkImage" id="image4007">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-open</property>
 			  <property name="icon_size">1</property>
@@ -8839,7 +8839,7 @@
 		      <signal name="activate" handler="on_edit_current_person_clicked" last_modification_time="Sun, 17 Oct 2004 11:43:33 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3903">
+			<widget class="GtkImage" id="image4008">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -8860,7 +8860,7 @@
 		      <signal name="activate" handler="on_show_all_person_events_activate" last_modification_time="Mon, 29 Aug 2005 09:51:24 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3904">
+			<widget class="GtkImage" id="image4009">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-index</property>
 			  <property name="icon_size">1</property>
@@ -8887,7 +8887,7 @@
 		      <signal name="activate" handler="on_delete_current_person_from_session_activate" last_modification_time="Thu, 28 Jul 2005 15:49:38 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3905">
+			<widget class="GtkImage" id="image4010">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -8999,7 +8999,7 @@
 			      <signal name="activate" handler="on_button_more_clicked" last_modification_time="Thu, 10 Mar 2005 18:52:25 GMT"/>
 
 			      <child internal-child="image">
-				<widget class="GtkImage" id="image3906">
+				<widget class="GtkImage" id="image4011">
 				  <property name="visible">True</property>
 				  <property name="stock">gtk-add</property>
 				  <property name="icon_size">1</property>
@@ -9024,7 +9024,7 @@
 		      <signal name="activate" handler="on_edit_selected_jump_clicked" last_modification_time="Sun, 17 Oct 2004 11:47:42 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3907">
+			<widget class="GtkImage" id="image4012">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -9045,7 +9045,7 @@
 		      <signal name="activate" handler="on_delete_selected_jump_clicked" last_modification_time="Tue, 19 Oct 2004 11:54:17 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3908">
+			<widget class="GtkImage" id="image4013">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -9111,7 +9111,7 @@
 			      <signal name="activate" handler="on_button_more_rj_clicked" last_modification_time="Fri, 11 Mar 2005 14:45:23 GMT"/>
 
 			      <child internal-child="image">
-				<widget class="GtkImage" id="image3909">
+				<widget class="GtkImage" id="image4014">
 				  <property name="visible">True</property>
 				  <property name="stock">gtk-add</property>
 				  <property name="icon_size">1</property>
@@ -9136,7 +9136,7 @@
 		      <signal name="activate" handler="on_edit_selected_jump_rj_clicked" last_modification_time="Sun, 07 Nov 2004 17:37:37 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3910">
+			<widget class="GtkImage" id="image4015">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -9157,7 +9157,7 @@
 		      <signal name="activate" handler="on_repair_selected_reactive_jump_clicked" last_modification_time="Wed, 07 Dec 2005 01:14:11 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3911">
+			<widget class="GtkImage" id="image4016">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-preferences</property>
 			  <property name="icon_size">1</property>
@@ -9178,7 +9178,7 @@
 		      <signal name="activate" handler="on_delete_selected_jump_rj_clicked" last_modification_time="Sun, 07 Nov 2004 17:37:37 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3912">
+			<widget class="GtkImage" id="image4017">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -9205,7 +9205,7 @@
 		      <signal name="activate" handler="on_jump_type_add_activate" last_modification_time="Thu, 10 Mar 2005 18:52:25 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3913">
+			<widget class="GtkImage" id="image4018">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-new</property>
 			  <property name="icon_size">1</property>
@@ -9319,6 +9319,15 @@
 			  </child>
 
 			  <child>
+			    <widget class="GtkMenuItem" id="menuitem_run_margaria">
+			      <property name="visible">True</property>
+			      <property name="label" translatable="yes">Margaria</property>
+			      <property name="use_underline">True</property>
+			      <signal name="activate" handler="on_run_extra_activate" last_modification_time="Mon, 02 Mar 2009 15:33:43 GMT"/>
+			    </widget>
+			  </child>
+
+			  <child>
 			    <widget class="GtkMenuItem" id="menuitem_run_shuttle">
 			      <property name="visible">True</property>
 			      <property name="label" translatable="yes">Shuttle run</property>
@@ -9350,7 +9359,7 @@
 			      <signal name="activate" handler="on_button_run_more_clicked" last_modification_time="Fri, 22 Apr 2005 14:37:06 GMT"/>
 
 			      <child internal-child="image">
-				<widget class="GtkImage" id="image3914">
+				<widget class="GtkImage" id="image4019">
 				  <property name="visible">True</property>
 				  <property name="stock">gtk-add</property>
 				  <property name="icon_size">1</property>
@@ -9375,7 +9384,7 @@
 		      <signal name="activate" handler="on_edit_selected_run_clicked" last_modification_time="Fri, 22 Apr 2005 14:34:58 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3915">
+			<widget class="GtkImage" id="image4020">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -9396,7 +9405,7 @@
 		      <signal name="activate" handler="on_delete_selected_run_clicked" last_modification_time="Fri, 22 Apr 2005 14:34:58 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3916">
+			<widget class="GtkImage" id="image4021">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -9471,7 +9480,7 @@
 			      <signal name="activate" handler="on_button_run_interval_more_clicked" last_modification_time="Tue, 16 Aug 2005 01:18:41 GMT"/>
 
 			      <child internal-child="image">
-				<widget class="GtkImage" id="image3917">
+				<widget class="GtkImage" id="image4022">
 				  <property name="visible">True</property>
 				  <property name="stock">gtk-add</property>
 				  <property name="icon_size">1</property>
@@ -9496,7 +9505,7 @@
 		      <signal name="activate" handler="on_edit_selected_run_interval_clicked" last_modification_time="Tue, 16 Aug 2005 12:33:39 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3918">
+			<widget class="GtkImage" id="image4023">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-edit</property>
 			  <property name="icon_size">1</property>
@@ -9517,7 +9526,7 @@
 		      <signal name="activate" handler="on_repair_selected_run_interval_clicked" last_modification_time="Wed, 03 May 2006 15:15:38 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3919">
+			<widget class="GtkImage" id="image4024">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-preferences</property>
 			  <property name="icon_size">1</property>
@@ -9538,7 +9547,7 @@
 		      <signal name="activate" handler="on_delete_selected_run_interval_clicked" last_modification_time="Tue, 16 Aug 2005 12:33:39 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3920">
+			<widget class="GtkImage" id="image4025">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-remove</property>
 			  <property name="icon_size">1</property>
@@ -9565,7 +9574,7 @@
 		      <signal name="activate" handler="on_run_type_add_activate" last_modification_time="Fri, 22 Apr 2005 14:34:58 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3921">
+			<widget class="GtkImage" id="image4026">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-new</property>
 			  <property name="icon_size">1</property>
@@ -9645,7 +9654,7 @@
 		      <signal name="activate" handler="on_menuitem_view_stats_activate" last_modification_time="Tue, 26 Jul 2005 23:54:29 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3922">
+			<widget class="GtkImage" id="image4027">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-refresh</property>
 			  <property name="icon_size">1</property>
@@ -9666,7 +9675,7 @@
 		      <signal name="activate" handler="on_show_report_activate" last_modification_time="Tue, 06 Sep 2005 09:10:32 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3923">
+			<widget class="GtkImage" id="image4028">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-refresh</property>
 			  <property name="icon_size">1</property>
@@ -9734,7 +9743,7 @@
 		      <signal name="activate" handler="on_menuitem_manual_activate" last_modification_time="Wed, 03 Oct 2007 23:31:41 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3924">
+			<widget class="GtkImage" id="image4029">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-info</property>
 			  <property name="icon_size">1</property>
@@ -9770,7 +9779,7 @@
 		      <signal name="activate" handler="on_about1_activate" last_modification_time="Wed, 22 Sep 2004 23:17:31 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3925">
+			<widget class="GtkImage" id="image4030">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-about</property>
 			  <property name="icon_size">1</property>
@@ -9797,7 +9806,7 @@
 		      <signal name="activate" handler="on_debug_crash_activate" last_modification_time="Thu, 23 Oct 2008 22:57:02 GMT"/>
 
 		      <child internal-child="image">
-			<widget class="GtkImage" id="image3926">
+			<widget class="GtkImage" id="image4031">
 			  <property name="visible">True</property>
 			  <property name="stock">gtk-dialog-error</property>
 			  <property name="icon_size">1</property>
@@ -11561,50 +11570,6 @@
 					      </child>
 
 					      <child>
-						<widget class="GtkButton" id="button_run_shuttle">
-						  <property name="visible">True</property>
-						  <property name="tooltip" translatable="yes">Shuttle Run Agility test</property>
-						  <property name="can_focus">True</property>
-						  <property name="label">Shuttle</property>
-						  <property name="use_underline">True</property>
-						  <property name="relief">GTK_RELIEF_NORMAL</property>
-						  <property name="focus_on_click">True</property>
-						  <signal name="clicked" handler="on_normal_run_activate" last_modification_time="Fri, 04 May 2007 15:53:40 GMT"/>
-						  <signal name="enter" handler="on_button_enter" last_modification_time="Wed, 02 May 2007 12:56:21 GMT"/>
-						</widget>
-						<packing>
-						  <property name="left_attach">3</property>
-						  <property name="right_attach">4</property>
-						  <property name="top_attach">1</property>
-						  <property name="bottom_attach">2</property>
-						  <property name="x_options">fill</property>
-						  <property name="y_options"></property>
-						</packing>
-					      </child>
-
-					      <child>
-						<widget class="GtkButton" id="button_run_zigzag">
-						  <property name="visible">True</property>
-						  <property name="tooltip" translatable="yes">ZigZag Agility test</property>
-						  <property name="can_focus">True</property>
-						  <property name="label">ZigZag</property>
-						  <property name="use_underline">True</property>
-						  <property name="relief">GTK_RELIEF_NORMAL</property>
-						  <property name="focus_on_click">True</property>
-						  <signal name="clicked" handler="on_normal_run_activate" last_modification_time="Fri, 04 May 2007 15:53:40 GMT"/>
-						  <signal name="enter" handler="on_button_enter" last_modification_time="Wed, 02 May 2007 12:56:21 GMT"/>
-						</widget>
-						<packing>
-						  <property name="left_attach">4</property>
-						  <property name="right_attach">5</property>
-						  <property name="top_attach">1</property>
-						  <property name="bottom_attach">2</property>
-						  <property name="x_options">fill</property>
-						  <property name="y_options"></property>
-						</packing>
-					      </child>
-
-					      <child>
 						<widget class="GtkButton" id="button_run_more">
 						  <property name="visible">True</property>
 						  <property name="tooltip" translatable="yes">More simple runs</property>
@@ -11696,6 +11661,72 @@
 						  <property name="y_options"></property>
 						</packing>
 					      </child>
+
+					      <child>
+						<widget class="GtkButton" id="button_run_zigzag">
+						  <property name="visible">True</property>
+						  <property name="tooltip" translatable="yes">ZigZag Agility test</property>
+						  <property name="can_focus">True</property>
+						  <property name="label">ZigZag</property>
+						  <property name="use_underline">True</property>
+						  <property name="relief">GTK_RELIEF_NORMAL</property>
+						  <property name="focus_on_click">True</property>
+						  <signal name="clicked" handler="on_normal_run_activate" last_modification_time="Fri, 04 May 2007 15:53:40 GMT"/>
+						  <signal name="enter" handler="on_button_enter" last_modification_time="Wed, 02 May 2007 12:56:21 GMT"/>
+						</widget>
+						<packing>
+						  <property name="left_attach">5</property>
+						  <property name="right_attach">6</property>
+						  <property name="top_attach">1</property>
+						  <property name="bottom_attach">2</property>
+						  <property name="x_options">fill</property>
+						  <property name="y_options"></property>
+						</packing>
+					      </child>
+
+					      <child>
+						<widget class="GtkButton" id="button_run_shuttle">
+						  <property name="visible">True</property>
+						  <property name="tooltip" translatable="yes">Shuttle Run Agility test</property>
+						  <property name="can_focus">True</property>
+						  <property name="label">Shuttle</property>
+						  <property name="use_underline">True</property>
+						  <property name="relief">GTK_RELIEF_NORMAL</property>
+						  <property name="focus_on_click">True</property>
+						  <signal name="clicked" handler="on_normal_run_activate" last_modification_time="Fri, 04 May 2007 15:53:40 GMT"/>
+						  <signal name="enter" handler="on_button_enter" last_modification_time="Wed, 02 May 2007 12:56:21 GMT"/>
+						</widget>
+						<packing>
+						  <property name="left_attach">4</property>
+						  <property name="right_attach">5</property>
+						  <property name="top_attach">1</property>
+						  <property name="bottom_attach">2</property>
+						  <property name="x_options">fill</property>
+						  <property name="y_options"></property>
+						</packing>
+					      </child>
+
+					      <child>
+						<widget class="GtkButton" id="button_run_margaria">
+						  <property name="visible">True</property>
+						  <property name="tooltip">Margaria-Kalamen test</property>
+						  <property name="can_focus">True</property>
+						  <property name="label">Margaria</property>
+						  <property name="use_underline">True</property>
+						  <property name="relief">GTK_RELIEF_NORMAL</property>
+						  <property name="focus_on_click">True</property>
+						  <signal name="clicked" handler="on_run_extra_activate" last_modification_time="Mon, 02 Mar 2009 15:33:22 GMT"/>
+						  <signal name="enter" handler="on_button_enter" last_modification_time="Wed, 02 May 2007 12:56:21 GMT"/>
+						</widget>
+						<packing>
+						  <property name="left_attach">3</property>
+						  <property name="right_attach">4</property>
+						  <property name="top_attach">1</property>
+						  <property name="bottom_attach">2</property>
+						  <property name="x_options">fill</property>
+						  <property name="y_options"></property>
+						</packing>
+					      </child>
 					    </widget>
 					    <packing>
 					      <property name="padding">0</property>

Added: trunk/images/margaria.png
==============================================================================
Binary file. No diff available.

Added: trunk/images/mini/margaria.png
==============================================================================
Binary file. No diff available.

Modified: trunk/src/chronojump.cs
==============================================================================
--- trunk/src/chronojump.cs	(original)
+++ trunk/src/chronojump.cs	Mon Mar  2 16:27:09 2009
@@ -104,6 +104,7 @@
 		Application.Run();
 	}
 
+	//variables to manage the ping thread
 	string versionAvailable;
 	bool pinging;
 	bool pulseGTKPingShouldEnd;
@@ -447,7 +448,6 @@
 		else
 			splashWin.CancelButtonShow(false);
 
-
 		Thread.Sleep (50);
 		return true;
 	}

Modified: trunk/src/execute/run.cs
==============================================================================
--- trunk/src/execute/run.cs	(original)
+++ trunk/src/execute/run.cs	Mon Mar  2 16:27:09 2009
@@ -290,12 +290,23 @@
 			" " + Catalog.GetString("speed") + ": " + Util.TrimDecimals ( (distance/time).ToString(), pDN );
 		appbar.Push( 1,myStringPush );
 
+
+		string description = "";
+		if(type == "Margaria") {
+			// P = W * 9.8 * D / t   
+			// W: person weight
+			// D: distance between 3d and 9th stair
+			double weight = SqlitePersonSession.SelectPersonWeight(personID, sessionID);
+			double distanceMM = distance / 1000;
+			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMM / time).ToString(), pDN) + " (Watts)";
+		}
+
 		uniqueID = SqliteRun.Insert(false, Constants.RunTable, "NULL", personID, sessionID, 
-				type, distance, time, "", //description
+				type, distance, time, description, 
 				Util.BoolToNegativeInt(simulated)); 
 		
 		//define the created object
-		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, "", Util.BoolToNegativeInt(simulated)); 
+		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, description, Util.BoolToNegativeInt(simulated)); 
 		
 		
 		//event will be raised, and managed in chronojump.cs

Modified: trunk/src/exportSession.cs
==============================================================================
--- trunk/src/exportSession.cs	(original)
+++ trunk/src/exportSession.cs	Mon Mar  2 16:27:09 2009
@@ -462,13 +462,16 @@
 
 			foreach (string runString in myRuns) {
 				string [] myStr = runString.Split(new char[] {':'});
+				string speed = "";
+				if(myStr[4] != "Margaria")
+					speed = Util.TrimDecimals(Util.GetSpeed(myStr[5], myStr[6], true), dec);//speed in m/s (true)
 
 				myData.Add (
 						myStr[2] + ":" +    			//personID
 						myStr[0] + ":" +  myStr[1] + ":" +  	//person.name, run.uniqueID
 						myStr[4] + ":" +  myStr[5] + ":" + 	//run.type, run.distance
 						Util.TrimDecimals(myStr[6], dec) + ":" +  	//run.time
-						Util.TrimDecimals(Util.GetSpeed(myStr[5], myStr[6], true), dec) + ":" + //speed in m/s (true)
+						speed + ":" + 				//speed in m/s (true)
 						Util.RemoveNewLine(myStr[7]) + ":" + Util.NoYes(myStr[8]) //description, simulated
 					   );
 			}

Modified: trunk/src/gui/chronojump.cs
==============================================================================
--- trunk/src/gui/chronojump.cs	(original)
+++ trunk/src/gui/chronojump.cs	Mon Mar  2 16:27:09 2009
@@ -117,6 +117,7 @@
 	[Widget] Gtk.Button button_run_20yard;
 	[Widget] Gtk.Button button_run_505;
 	[Widget] Gtk.Button button_run_illinois;
+	[Widget] Gtk.Button button_run_margaria;
 	[Widget] Gtk.Button button_run_shuttle;
 	[Widget] Gtk.Button button_run_zigzag;
 	[Widget] Gtk.Button button_run_interval_by_laps;
@@ -169,6 +170,7 @@
 	[Widget] Gtk.MenuItem menuitem_run_20yard;
 	[Widget] Gtk.MenuItem menuitem_run_505;
 	[Widget] Gtk.MenuItem menuitem_run_illinois;
+	[Widget] Gtk.MenuItem menuitem_run_margaria;
 	[Widget] Gtk.MenuItem menuitem_run_shuttle;
 	[Widget] Gtk.MenuItem menuitem_run_zigzag;
 	[Widget] Gtk.MenuItem menuitem_run_interval_by_laps;
@@ -2374,6 +2376,8 @@
 			currentEventType = new RunType("Agility-505");
 		} else 	if(o == (object) button_run_illinois) {
 			currentEventType = new RunType("Agility-Illinois");
+		} else 	if(o == (object) button_run_margaria) {
+			currentEventType = new RunType("Margaria");
 		} else 	if(o == (object) button_run_shuttle) {
 			currentEventType = new RunType("Agility-Shuttle-Run");
 		} else 	if(o == (object) button_run_zigzag) {
@@ -2930,6 +2934,8 @@
 	
 		if(o == (object) button_run_custom || o == (object) menuitem_run_custom) {
 			currentRunType = new RunType("Custom");
+		} else if (o == (object) button_run_margaria || o == (object) menuitem_run_margaria) {
+			currentRunType = new RunType("Margaria");
 		}
 		// add others...
 		

Modified: trunk/src/gui/run.cs
==============================================================================
--- trunk/src/gui/run.cs	(original)
+++ trunk/src/gui/run.cs	Mon Mar  2 16:27:09 2009
@@ -812,12 +812,12 @@
 	[Widget] Gtk.Label label_limit_units;
 	[Widget] Gtk.Label label_distance;
 	[Widget] Gtk.SpinButton distance_limit;
-	[Widget] Gtk.Label label_meters;
+	[Widget] Gtk.Label label_distance_units;
 	[Widget] Gtk.Window run_extra;
 	[Widget] Gtk.SpinButton spinbutton_distance;
 	[Widget] Gtk.Button button_accept;
 
-	static int distance = 100;
+	static int distance;
 	static int limited = 10;
 	static bool tracksLimited;
 	
@@ -862,6 +862,13 @@
 			hideDistanceData();	
 		}
 		
+		if(myRunType.Name == "Margaria") {
+			RunExtraWindowBox.label_distance.Text = Catalog.GetString("Vertical distance between\nstairs third and nine.");
+			RunExtraWindowBox.label_distance_units.Text = Catalog.GetString("Millimeters.");
+			distance = 1050;
+		} else
+			distance = 100;
+		
 		RunExtraWindowBox.spinbutton_distance.Value = distance;
 		RunExtraWindowBox.spinbutton_limit.Value = limited;
 		
@@ -879,7 +886,7 @@
 	static void hideDistanceData () {
 		RunExtraWindowBox.label_distance.Sensitive = false;
 		RunExtraWindowBox.spinbutton_distance.Sensitive = false;
-		RunExtraWindowBox.label_meters.Sensitive = false;
+		RunExtraWindowBox.label_distance_units.Sensitive = false;
 	}
 	
 	void on_button_cancel_clicked (object o, EventArgs args)

Modified: trunk/src/runType.cs
==============================================================================
--- trunk/src/runType.cs	(original)
+++ trunk/src/runType.cs	Mon Mar  2 16:27:09 2009
@@ -154,7 +154,7 @@
 		} 
 		else if(name == "Agility-505") {
 			hasIntervals 	= false; 
-			distance 	= 10;
+			distance 	= -1;
 			tracksLimited 	= false;
 			fixedValue 	= 0;
 			isPredefined	= true;
@@ -259,6 +259,25 @@
 
 				"http://www.topendsports.com/testing/tests/zigzag.htm"; + "\n" +
 	    			Catalog.GetString("Cited with permission.");
+		} 
+		else if(name == "Margaria") {
+			hasIntervals 	= false; 
+			distance 	= 0; //0:will ask user... refered to the vertical distance between third and nineth stair
+			tracksLimited 	= false;
+			fixedValue 	= 0;
+			isPredefined	= true;
+			imageFileName = "margaria.png";
+			description	= Catalog.GetString("Margaria-Kalamen");
+			longDescription	= "";
+			/*
+				"<b>" + Catalog.GetString("Procedure") + "</b>: " +
+				Catalog.GetString("Markers are set up 5 and 15 meters from a line marked on the ground. The athlete runs from the 15 meter marker towards the line (run in distance to build up speed) and through the 5 m markers, turns on the line and runs back through the 5 m markers. The time is recorded from when the athletes first runs through the 5 meter marker, and stopped when they return through these markers (that is, the time taken to cover the 5 m up and back distance - 10 m total). The best of two trails is recorded. The turning ability on each leg should be tested. The subject should be encouraged to not overstep the line by too much, as this will increase their time.") + "\n\n" +
+				
+				"<b>" + Catalog.GetString("Comments") + "</b>: " + 
+				Catalog.GetString("This is a test of 180 degree turning ability. This ability may not be applicable to some sports.") + "\n\n" +
+				"http://www.topendsports.com/testing/tests/505.htm"; + "\n" +
+	    			Catalog.GetString("Cited with permission.");
+				*/
 		} //interval
 		else if(name == "byLaps") {
 			hasIntervals 	= true; 

Modified: trunk/src/sqlite/main.cs
==============================================================================
--- trunk/src/sqlite/runType.cs	(original)
+++ trunk/src/sqlite/runType.cs	Mon Mar  2 16:27:09 2009
@@ -65,6 +65,7 @@
 			"400m:400:run 400 meters",
 			"1000m:1000:run 1000 meters",
 			"2000m:2000:run 2000 meters",
+			"Margaria:0:Margaria-Kalamen test",
 
 			//also simple agility tests
 			"Agility-20Yard:18.28:20Yard Agility test",
@@ -243,6 +244,7 @@
 		SqliteEvent.GraphLinkInsert (Constants.RunTable, "Agility-Illinois", "agility_illinois.png", true);
 		SqliteEvent.GraphLinkInsert (Constants.RunTable, "Agility-Shuttle-Run", "agility_shuttle.png", true);
 		SqliteEvent.GraphLinkInsert (Constants.RunTable, "Agility-ZigZag", "agility_zigzag.png", true);
+		SqliteEvent.GraphLinkInsert (Constants.RunTable, "Margaria", "margaria.png", true);
 	}
 
 

Modified: trunk/src/treeViewRun.cs
==============================================================================
--- trunk/src/treeViewRun.cs	(original)
+++ trunk/src/treeViewRun.cs	Mon Mar  2 16:27:09 2009
@@ -88,11 +88,20 @@
 		int count = 0;
 		myData[count++] = title;
 		//myData[count++] = Util.TrimDecimals(newRun.Speed.ToString(), pDN); this doesn't know the metersSecondsPreferred
-		myData[count++] = Util.TrimDecimals(Util.GetSpeed(
-					newRun.Distance.ToString(),
-					newRun.Time.ToString(),
-					metersSecondsPreferred ), pDN);
-		myData[count++]	= Util.TrimDecimals(newRun.Distance.ToString(), pDN);
+		if(newRun.Type == "Margaria") 
+			myData[count++] = ""; //don't show speed, because has no sense on Margaria
+		else {
+			myData[count++] = Util.TrimDecimals(Util.GetSpeed(
+						newRun.Distance.ToString(),
+						newRun.Time.ToString(),
+						metersSecondsPreferred ), pDN);
+		}
+		
+		string distanceUnits = "";
+		if(newRun.Type == "Margaria") 
+			distanceUnits = " mm";
+		myData[count++]	= Util.TrimDecimals(newRun.Distance.ToString(), pDN) + distanceUnits;
+
 		myData[count++] = Util.TrimDecimals(newRun.Time.ToString(), pDN);
 		myData[count++] = newRun.Description;
 		myData[count++] = newRun.UniqueID.ToString();

Modified: trunk/version.txt
==============================================================================
--- trunk/version.txt	(original)
+++ trunk/version.txt	Mon Mar  2 16:27:09 2009
@@ -1 +1 @@
-0.8.2.3
+0.8.2.4



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/src/sqlite/main.cs	(original)
+++ trunk/src/sqlite/main.cs	Mon Mar  2 16:27:09 2009
@@ -72,7 +72,7 @@
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "0.63";
+	static string lastChronojumpDatabaseVersion = "0.64";
 
 	public Sqlite() {
 	}
@@ -812,6 +812,22 @@
 				dbcon.Close();
 				currentVersion = "0.63";
 			}
+			if(currentVersion == "0.63") {
+				dbcon.Open();
+				
+				RunType type = new RunType();
+				type.Name = "Margaria";
+				type.Distance = 0;
+				type.Description = "Margaria-Kalamen test";
+				SqliteRunType.Insert(type, Constants.RunTypeTable, true);
+
+				SqliteEvent.GraphLinkInsert (Constants.RunTable, "Margaria", "margaria.png", true);
+				SqlitePreferences.Update ("databaseVersion", "0.64", true); 
+				
+				Log.WriteLine("Converted DB to 0.64 (added margaria test)"); 
+				dbcon.Close();
+				currentVersion = "0.64";
+			}
 
 
 		}
@@ -929,7 +945,8 @@
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
 		//0.62 - 0.63 Converted DB to 0.63 (added 'versionAvailable' to preferences)
 		//0.61 - 0.62 added hexagon (jumpRj test)
 		//0.60 - 0.61 added RunIntervalType distancesString (now we van have interval tests with different distances of tracks). Added MTGUG
 		//0.59 - 0.60 added volumeOn and evaluatorServerID to preferences. Session has now serverUniqueID. Simulated now are -1, because 0 is real and positive is serverUniqueID
@@ -929,7 +945,8 @@
 		
 		//changes [from - to - desc]
-		//0.62 - 0.63 Converted DB to 0.63 (added 'versionAvailable' to preferences)
+		//0.63 - 0.64 added margaria test
+		//0.62 - 0.63 added 'versionAvailable' to preferences
 		//0.61 - 0.62 added hexagon (jumpRj test)
 		//0.60 - 0.61 added RunIntervalType distancesString (now we van have interval tests with different distances of tracks). Added MTGUG

Modified: trunk/src/sqlite/runType.cs
==============================================================================